# Changelog Lenovo ThinkPad T530 OpenCore

> **Tested with**: macOS High Sierra (10.13), Mojave (10.14), Catalina (10.15), Big Sur (11.5) and Monterey (12.0)</br>
**Recommended OS**: macOS Catalina; **SMBIOS**: MacBookPro10,1

## 2021-08-03
- Updated OpenCore to 0.7.2 Release.
- Updated `Drivers`, `Kexts` and `Resources`.
- **ACPI**:
	- Updated `SSDT-PNLF.aml` based on latest ACPI Samples to improve Windows Compatibility
- **CONFIG**:
	- Updated `config.plist` to reflect latest OpenCore feature-set.
	- Added `config_Monterey.plist`
	- Audio: changed Layout-ID from `29` to `28` → Fixes line-out level being lower than normal if speakers/headphones are plugged-in during boot.
	- Updated `Arch` and `MinKernel` Infos
	- Changed UEFI > APFS > `MinDate` and `MinVersion` to `-1` → Enables APFS Driver loading for *any* macOS Version. Otherwise, if you use macOS lower than Big Sur and the values are left to defaults (set to `0`) you won't see your macOS Partition. **NOTE**: For security reasons you should change these values according to the macOS version you are running. A list with the correct values can be found [here](https://github.com/acidanthera/OpenCorePkg/blob/master/Include/Acidanthera/Library/OcApfsLib.h).

## 2021-07-08

- Merged regular EFI Folder and Monterey Edition 
- Added `config_Monterey.plist` to the EFI Folder. Rename to `config.plist` to boot macOS 12.0 beta
- Added `BluetoolFixup.kext` for making Bluetooth work in macOS 12 beta

## 2021-07-06
- Updated OpenCore to 0.7.2 Nightly.
- Updated `Drivers`, `Kexts` and `Resources`.
- Updated `config.plist` to reflect latest OpenCore feature-set.
- reinstated `framebuffer-unifiedmem` in Framebuffer Patch for 2 GB graphics RAM to fix small glitches.

**NOTE**: Configured for use with macOS Catalina primarily. Big Sur needs changes in SMBIOS as well as csr-active config. macOS Monterey needs a different EFI altogether (check `Releses` Section) plus modifications to the Installation itself to patch in Intel HD4000 graphics support. Follow the EFI install Instruction on my github repo.

## 2021-06-07
- Updated OpenCore to 0.7.0 Release Version.
- Updated `Drivers`, `Kexts` and `Resources`.
- Fixed Brightness Fn Keys not working under Windows 10.
- Removed `BrightnessKeys.kext` and corresponding binary rename in favor of `SSDT-BKEYS.aml` to enable Brightness Fn Keys → ACPI method is cleaner, plus it's one less Kext to worry about in the future.
- **ACPI:**
	- Added `SSDT-BKEYS.aml` → enables Brightness Fn Keys
	- Added `SSDT-XDSM.aml` → restricts `_DSM` to `XDSM`rename to specified devices in macOS only.
	- Removed `SSDT-XCPM.aml` for enabling `X86PlatformPlugin` → there are no benefits in using it on Ivy Bridge CPUs. If anything, performance is reduced significantly.
- **CONFIG:**
	- Updated `config.plist` to reflect latest OpenCore feature-set.
	- Updated Comments.
	- Enabled new `AllowToggleSip` feature → Adds option to override the current setting for `csr-active-config` to the BootPicker, thereby temporarily enabling/disabling SIP. In other words: if SIP is disabled by default it enables it and if SIP is on, it turns it off until next boot.
	- Changed `PickerVariant` to `Acidanthera/GoldenGate` to test new content flavor system. *GoldenGate* = BigSur Icon Set. Default = `Auto`.
	- Added `DMAR` and `MATS` to `ACPI > Delete` to drop these Tables.
	- Added placeholder entries (commented-out by `#`) with values for `Syrah Black` and `Light Grey` to NVRAM > Add > 4D1EDE05-38C7-4A6A-9CC6-4BCCA8B38C14 > `DefaultBackgroundColor`
	- Re-enabled `ActivateHpetSupport` Quirk for improved Hyper Threading performance.
	- Re-enabled `_DSM` to `XDSM` rename → fixes machine not entering sleep on it's own.
	- Re-enabled `_Q14` to `XQ14` and `_Q15` to `XQ15`renames to make Brightness Fn Keys work without `BrightnessKeys.kext`. Added `base` ACPI path to limit these renames to specified location.
	- Disabled Misc > Debug > `AppleDebug` and `ApplePanic`
	- Disabled `framebuffer-unifiedmem` (2048 MB stolen) in favor of `framebuffer-stolenmem` (1536 MB stolen) in Device Properties > `PciRoot(0x0)/Pci(0x2,0x0)`as recommended by Framebuffer Patching Guide → more responsive GUI and faster website display.
	- Deleted unnecessary `ACST` to `OCST` rename.
	- Deleted `DSDT` as target `TableSignature` for `change PCI0.VID to IGPU` renames → Fixes Brightness Fn Keys under Windows.

**NOTE:** This EFI is completed, imo. Any future release will probably be maintenance updates only – if any.

## 2021-05-12
- Updated OpenCore to the latest commit of 0.7.0 nightly
- Updated Drivers and Kexts
- Fixed Hibernation. System wouldn't enter Hibernation properly on its own.
- Added `BrightnessKeys.kext` to get rid of binary renames and additional SSDT necessary to make Brightness Keys work in macOS.
- **CONFIG:**
	- Updated Config to reflect latest feature-set
	- Removed DSDT-based config → no longer necessary
	- Added `Name (NBCF, 0x00)` to `Name (NBCF, 0x01)` rename so `BrightnessKeys.kext`works.
	- Added `FixACST` **Background**: The system `DSDT.aml` contains the method `ACST` in `PSR`(= Power Source) for device `AC`, but ACST is also used by macOS 10.8+ to control C-States! As a result, a completely implicit conflict with very unclear behavior can occur. This fix renames all occurrences of `ACST` to `OCST`.
	- Deleted `CMOR to XMOR` rename
	- Deleted `_Q14 to XQ14` and `_Q15 to XQ15`→ no longer necessary since `BrightnessKeys.kext` is used to make Brightness Keys work instead.
- **ACPI:**
	- Updated `SSDT-XOSI.aml` → added latest version of Windows 10
	- Removed `SSDT-BKeys-Q14Q15.aml` → no longer necessary since `BrightnessKeys.kext` is used
	- Removed `SSDT-CMOR.aml` → didn't improve Fan behavior at all
	- Removed `SSDT-ThinkPad-Fan.aml`→ didn't improve Fan behavior
	- Removed `SSDT-XDSM.aml`→ deleted for max compatibility with Windows
	
## 2021-05-03

- Updated OpenCore to version 0.7.0 nightly
- **CONFIG**:
	- Updated config to reflect the latest OpenCore feature-set
	- Removed unused Framebuffer Patch from `DeviceProperties`
	- Corrected wrong value in `#csr-active-config (High Sierra)`
	- Changed `ExposeSensitiveData`to `7` to display OpenCore build info in BootPicker
	- Disabled `ActivateHpetSupport` to increase performance.
	- Added `SAT1 to SATA` rename
	- Added `XCHI to XHC` rename
	- Added `_DSM to XDSM` rename
	- Removed `XHC1 to SHCI` rename → Device doesn't exist in `DSDT`
	- Removed `GPRW to XPRW` rename → Method doesn't exist in `DSDT`
	- Re-enabled `ConnectDrivers` for maximum compatibilty
- **KEXTs**:
	- Updated Kexts
	- Deleted unused Plugins from `VoodooPS2Controller.kext` and `config.plist`.
	- Updated entries and comments for `AirportBrcmFixup` and `BrcmBluetoothInjector`
- **ACPI**:
 	- Replaced `SSDT-SBUS-MCHC.aml` with the latest official version by Acidanthera
 	- Removed `SSDT-GPRW.aml` → method doesn't exist in `DSDT`
	- Changed device names and methods in `SSDT-XDSM.aml` to be consistent with renames used in `config.plist`
 	- Replaced `SSDT-OC-XOSI.aml` by the one from Dortania
	- Edited Windows entries in `SSDT-XOSI.aml` to reflect those present in `DSDT`, added entry for current Windows 10 build (20H2)
	
## 2021-04-05

- Upated OpenCore to version 0.6.9 nightly
- Updated Config.plist with new Array `AppleEvent` under `UEFI`
- Remove unused/moved entries from `config.plist`
- Updated Resources
- Updated `HfsPlus` Driver
- Added missing Parameters `Base`and `BaseSkip` to some ACPI > Patch entries 
- Renamed USB Controllers `EHC1`,`EHC2` and `XHC1`to avoid possible USB conflicts. Use Terminal to check the following. If nothing returns, you're good:
	- `ioreg -l -p IOService -w0 | grep -i EHC1`
	- `ioreg -l -p IOService -w0 | grep -i EHC2`
 	- `ioreg -l -p IOService -w0 | grep -i XHC1`
- Fixed Kernel > Patch CapriConnectors Patch for HDMI Connectors. Disabled, since unused.
- Validated config. 1 Error. Can be ignored.

**NOTE**: don't edit the config with OpenCore Configurator. It adds back in features which are no longer used, thereby producing errors on boot

## 2021-04-02

- Updated OpenCore to v0.6.8
- **KEXTs**:
	- Reverted `VoodooPS2Controller.kext` to a fixed variant of v 1.9.2 compatible with the current OpenCore versions > working flawlessly, no trackpad deadzones, super smooth and precice reaction!
	- fixed `TrackPoint` scrolling. X and Y multipliers were way too high - reduced them from `20` to `2` and now it is useable again.
- **ACPI**:
	- sorted out all the renames and organized them alphabetically
	- Renamed ACPI Hotpatches for a tidier look
	- added comments to Renames and SSDTs  
	- Added/replaced the following SSDTs:
		- `CMOR to XMOR` Rename, paired with `SSDT-CMOR.aml` to deactive `DSDT` Fan Control method and replace it with `SSDT-ThinkPad-Fan.aml` for changing system fan behavior
		- `SSDT-EXT4.aml` → From here…
		- `SSDT-EXT5.aml`
		- `SSDT-GPRW.aml`
		- `SSDT-LID.aml` … to here: new SSDTs for fixing sleep wake, Lid and power LED 
		- `SSDT-XDSM.aml` → disables certain devices in system `DSDT` so they can be replaced
- **Performance Improvements**:
	- System runs steadier in idle - almost no cpu spikes -> less Fan activity
	- System reacts snappier overall
	- Benchmark improved again. This is as good as it gets. 
	- **NOTE**: Stay on macOS Catalina. The performence is just better.
- **Remaining Issues** (still):
	- ~~LED pulsing after quitting sleep~~ FIXED!
	- On Lid Close
		- no Hibernation when closing the Lid
		- no switching over the primary display to external monitor (Clamshell Mode). It works without issues in Clover, in OC I couldn't figure it out yet :( Maybe I can utilize the "base" parameter insdie of renames to address it.

## 2021-03-07

* Updated OpenCore and Drivers to version 0.6.8
* **Kexts**:
	* Updated all Kexts
	* Added `BrcmFirmwareData.kext`. Delete `BrcmFirmwareRepo.kext` from Library > Extensions if present to keep it Vanilla.
	* Removed unneccessary kexts (`SMC Sensors` and `NoTouchID`)
	* Replaced `VoodooPS2Controller.kext` 1.9.2 with 2.2.2. The version from Rehabman has become incompatible with OpenCore and prevents boot.
* **ACPI**:
	* Added`SSDT-ThinkPad_TrackPad.aml` to make Trackpad work. Tweaked a few parameters to make it feel less sluggish. Still not as good as before.
	* Added `SSDT-ThinkPad-Fan.aml`
	* Fixed Windows ACPI Errors when using `config_DSDT.plist`. Windows 10 can now be started when using the config based on the patched DSDT.
* Enabled Mouse Support for Bootpicker (`PickerAttributes` = 17)
* Disconnected drivers to reduce waiting time between Lenovo Logo and Bootpicker
* Disabled Boot Chime and removed `AudioDXE.efi`
* Enabled `ActivateHpetSupport` Quirk

**NOT Working**: the new VoodooPS2 Controller Kext breaks Mouse Button Support when using `config_DSDT.plist`. Use DSDT-less config instead!

## NOTES

- The color coding used in the `ACPI` folder refers to `.aml` files used with the dsdt-less `config.plist`: <span style="color:green">**GREEN = enabled and working**</span>, <span style="color:gray"></br>**GRAY = disabled**</span>, because these are only used with the DSDT_config.plist.
- Color coding in `Kext` folder: <span style="color:red">**RED = don't update this Kext!**</span>
- `SSDT-XCPM.aml` is experimental and also disabled by default. Don't enable it! Read this first: [Enabling XCPM for Ivy Bridge](https://github.com/5T33Z0/Lenovo-T530-Hackinosh-OpenCore/blob/main/Guides/Enable%20XCPM.md).
